@@ -364,7 +364,7 @@ from math import e, pi
 
 
 # Define ufl.* namespace
-from ufl.utils.py23 import as_native_strings
+from ufl.utils.str import as_native_strings
 __all__ = as_native_strings([
     'product',
     'get_handler', 'get_logger', 'set_handler', 'set_level', 'add_logfile',
