@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 """Utility algorithms for inspection of and information extraction from UFL objects in various ways."""
 
-# Copyright (C) 2008-2014 Martin Sandve Alnes
+# Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
 # This file is part of UFL.
 #
@@ -21,30 +22,19 @@
 # Modified by Johan Hake, 2010.
 
 from itertools import chain
-from six.moves import zip
-from collections import namedtuple
 
-from ufl.log import error, warning, info
-from ufl.assertions import ufl_assert
-from ufl.sorting import topological_sorting
-from ufl.utils.sorting import sorted_by_count
+from ufl.log import error
+from ufl.utils.sorting import sorted_by_count, topological_sorting
 
-from ufl.core.expr import Expr
 from ufl.core.terminal import Terminal, FormArgument
-from ufl.finiteelement import MixedElement, RestrictedElement
 from ufl.argument import Argument
 from ufl.coefficient import Coefficient
-from ufl.variable import Variable
-from ufl.core.multiindex import Index, MultiIndex
-from ufl.geometry import Domain
-from ufl.integral import Measure, Integral
-from ufl.form import Form
 from ufl.algorithms.traversal import iter_expressions
-from ufl.corealg.traversal import pre_traversal, traverse_terminals
+from ufl.corealg.traversal import unique_pre_traversal, traverse_unique_terminals
 
 
-# TODO: Some of these can possibly be optimised by implementing inlined stack based traversal algorithms
-
+# TODO: Some of these can possibly be optimised by implementing
+# inlined stack based traversal algorithms
 
 def _sorted_by_number_and_part(seq):
     return sorted(seq, key=lambda x: (x.number(), x.part()))
@@ -61,14 +51,15 @@ def unique_tuple(objects):
     return tuple(unique_objects)
 
 
-#--- Utilities to extract information from an expression ---
+# --- Utilities to extract information from an expression ---
 
 def __unused__extract_classes(a):
     """Build a set of all unique Expr subclasses used in a.
     The argument a can be a Form, Integral or Expr."""
     return set(o._ufl_class_
                for e in iter_expressions(a)
-               for o in pre_traversal(e))
+               for o in unique_pre_traversal(e))
+
 
 def extract_type(a, ufl_type):
     """Build a set of all objects of class ufl_type found in a.
@@ -76,44 +67,49 @@ def extract_type(a, ufl_type):
     if issubclass(ufl_type, Terminal):
         # Optimization
         return set(o for e in iter_expressions(a)
-                   for o in traverse_terminals(e)
+                   for o in traverse_unique_terminals(e)
                    if isinstance(o, ufl_type))
     else:
         return set(o for e in iter_expressions(a)
-                   for o in pre_traversal(e)
+                   for o in unique_pre_traversal(e)
                    if isinstance(o, ufl_type))
 
+
 def has_type(a, ufl_type):
     """Return if an object of class ufl_type can be found in a.
     The argument a can be a Form, Integral or Expr."""
     if issubclass(ufl_type, Terminal):
         # Optimization
-        traversal = traverse_terminals
+        traversal = traverse_unique_terminals
     else:
-        traversal = pre_traversal
+        traversal = unique_pre_traversal
     return any(isinstance(o, ufl_type) for e in iter_expressions(a) for o in traversal(e))
 
+
 def has_exact_type(a, ufl_type):
     """Return if an object of class ufl_type can be found in a.
     The argument a can be a Form, Integral or Expr."""
     tc = ufl_type._ufl_typecode_
     if issubclass(ufl_type, Terminal):
         # Optimization
-        traversal = traverse_terminals
+        traversal = traverse_unique_terminals
     else:
-        traversal = pre_traversal
+        traversal = unique_pre_traversal
     return any(o._ufl_typecode_ == tc for e in iter_expressions(a) for o in traversal(e))
 
+
 def extract_arguments(a):
     """Build a sorted list of all arguments in a,
     which can be a Form, Integral or Expr."""
     return _sorted_by_number_and_part(extract_type(a, Argument))
 
+
 def extract_coefficients(a):
     """Build a sorted list of all coefficients in a,
     which can be a Form, Integral or Expr."""
     return sorted_by_count(extract_type(a, Coefficient))
 
+
 def extract_arguments_and_coefficients(a):
     """Build two sorted lists of all arguments and coefficients
     in a, which can be a Form, Integral or Expr."""
@@ -153,7 +149,7 @@ The arguments found are:\n%s""" % "\n".join("  %s" % f for f in coefficients)
 def extract_elements(form):
     "Build sorted tuple of all elements used in form."
     args = chain(*extract_arguments_and_coefficients(form))
-    return tuple(f.element() for f in args)
+    return tuple(f.ufl_element() for f in args)
 
 
 def extract_unique_elements(form):
@@ -164,26 +160,11 @@ def extract_unique_elements(form):
 def extract_sub_elements(elements):
     "Build sorted tuple of all sub elements (including parent element)."
     sub_elements = tuple(chain(*[e.sub_elements() for e in elements]))
-    if not sub_elements: return tuple(elements)
+    if not sub_elements:
+        return tuple(elements)
     return tuple(elements) + extract_sub_elements(sub_elements)
 
 
-def __unused__extract_unique_sub_elements(elements):
-    "Build sorted tuple of all unique sub elements (including parent element)."
-    return unique_tuple(extract_sub_elements(elements))
-
-
-def __unused__extract_element_map(elements):
-    "Build map from elements to element index in ordered tuple."
-    element_map = {}
-    unique_elements = unique_tuple(elements)
-    for element in elements:
-        indices = [i for (i, e) in enumerate(unique_elements) if e == element]
-        ufl_assert(len(indices) == 1, "Unable to find unique index for element.")
-        element_map[element] = i
-    return element_map
-
-
 def sort_elements(elements):
     """
     Sort elements so that any sub elements appear before the
@@ -194,7 +175,7 @@ def sort_elements(elements):
     """
 
     # Set nodes
-    nodes = elements
+    nodes = sorted(elements)
 
     # Set edges
     edges = dict((node, []) for node in nodes)
