@@ -20,7 +20,7 @@
 #
 # Modified by Massimiliano Leoni, 2016
 
-from ufl.utils.py23 import as_native_str
+from ufl.utils.str import as_native_str
 
 
 def attach_ufl_id(cls):
