@@ -18,14 +18,12 @@
 #
 # Modified by Massimiliano Leoni, 2016
 
-# import six
-from ufl.utils.py23 import as_native_str
-from ufl.utils.py23 import as_native_strings
+from ufl.utils.str import as_native_str
+from ufl.utils.str import as_native_strings
 from ufl.finiteelement.finiteelementbase import FiniteElementBase
 from ufl.sobolevspace import HDiv, HCurl
 
 
-# @six.python_2_unicode_compatible
 class HDivElement(FiniteElementBase):
     """A div-conforming version of an outer product element, assuming
     this makes mathematical sense."""
@@ -64,7 +62,6 @@ class HDivElement(FiniteElementBase):
         return "HDivElement(%s)" % str(self._element.shortstr())
 
 
-# @six.python_2_unicode_compatible
 class HCurlElement(FiniteElementBase):
     """A curl-conforming version of an outer product element, assuming
     this makes mathematical sense."""
