@@ -25,7 +25,6 @@ objects."""
 # Modified by Massimiliano Leoni, 2016.
 
 import operator
-from six.moves import xrange as range
 
 from ufl.log import error, warning
 from ufl.form import Form
@@ -41,7 +40,7 @@ from ufl.conditional import EQ, NE, \
 from ufl.mathfunctions import Sqrt, Exp, Ln, Erf,\
     Cos, Sin, Tan, Cosh, Sinh, Tanh, Acos, Asin, Atan, Atan2,\
     BesselJ, BesselY, BesselI, BesselK
-from ufl.restriction import CellAvg, FacetAvg
+from ufl.averaging import CellAvg, FacetAvg
 from ufl.core.multiindex import indices
 from ufl.indexed import Indexed
 from ufl.geometry import SpatialCoordinate, FacetNormal
