@@ -18,8 +18,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with UFL. If not, see <http://www.gnu.org/licenses/>.
 
-from six import string_types
-
 
 def camel2underscore(name):
     "Convert a CamelCaps string to underscore_syntax."
@@ -68,7 +66,7 @@ def tstr(t, colsize=80):
     s = ""
     for (key, value) in t:
         key = str(key)
-        if isinstance(value, string_types):
+        if isinstance(value, str):
             value = "'%s'" % value
         else:
             value = str(value)
